decode

Function decode 

pub fn decode(data: &[u8]) -> Result<Vec<f32>, JsValue>
decode flo file to samples

This automatically detects whether the file uses lossless or lossy encoding and dispatches to the appropriate decoder.

Arguments

  • data - flo™ file bytes

Returns

Interleaved audio samples (f32, -1.0 to 1.0)